==> qtjambi-designer-5.15.10-sources.jar: io/qt/designer/QDesignerWidgetDataBaseInterface.java <==
package io.qt.designer;


/**
 * <p>Java wrapper for Qt class QDesignerWidgetDataBaseInterface</p>
 */
public class QDesignerWidgetDataBaseInterface extends io.qt.core.QObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QDesignerWidgetDataBaseInterface.class);
    

    public final Signal0 changed = new Signal0();
    
    /**
     * <p>Overloaded constructor for {@link #QDesignerWidgetDataBaseInterface(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QDesignerWidgetDataBaseInterface() {
        this((io.qt.core.QObject)null);
    }
    
    public QDesignerWidgetDataBaseInterface(io.qt.core.QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QDesignerWidgetDataBaseInterface instance, io.qt.core.QObject parent);
    
    /**
     * <p>Overloaded function for {@link #isContainer(io.qt.core.QObject, boolean)}
     *  with <code>resolveName = true</code>.</p>
     */
    @io.qt.QtUninvokable
    public final boolean isContainer(io.qt.core.QObject object) {
        return isContainer(object, (boolean)true);
    }
    
    @io.qt.QtUninvokable
    public final boolean isContainer(io.qt.core.QObject object, boolean resolveName){
        return isContainer_native_QObject_ptr_bool_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(object), resolveName);
    }
    
    @io.qt.QtUninvokable
    private native boolean isContainer_native_QObject_ptr_bool_constfct(long __this__nativeId, long object, boolean resolveName);
    
    /**
     * <p>Overloaded function for {@link #isCustom(io.qt.core.QObject, boolean)}
     *  with <code>resolveName = true</code>.</p>
     */
    @io.qt.QtUninvokable
    public final boolean isCustom(io.qt.core.QObject object) {
        return isCustom(object, (boolean)true);
    }
    
    @io.qt.QtUninvokable
    public final boolean isCustom(io.qt.core.QObject object, boolean resolveName){
        return isCustom_native_QObject_ptr_bool_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(object), resolveName);
    }
    
    @io.qt.QtUninvokable
    private native boolean isCustom_native_QObject_ptr_bool_constfct(long __this__nativeId, long object, boolean resolveName);
    
    @io.qt.QtUninvokable
    public void append(io.qt.designer.QDesignerWidgetDataBaseItemInterface item){
        append_native_QDesignerWidgetDataBaseItemInterface_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(item));
    }
    
    @io.qt.QtUninvokable
    private native void append_native_QDesignerWidgetDataBaseItemInterface_ptr(long __this__nativeId, long item);
    
    @io.qt.QtUninvokable
    public io.qt.designer.QDesignerFormEditorInterface core(){
        return core_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.designer.QDesignerFormEditorInterface core_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public int count(){
        return count_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int count_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public int indexOf(io.qt.designer.QDesignerWidgetDataBaseItemInterface item){
        return indexOf_native_QDesignerWidgetDataBaseItemInterface_ptr_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(item));
    }
    
    @io.qt.QtUninvokable
    private native int indexOf_native_QDesignerWidgetDataBaseItemInterface_ptr_constfct(long __this__nativeId, long item);
    
    /**
     * <p>Overloaded function for {@link #indexOfClassName(java.lang.String, boolean)}
     *  with <code>resolveName = true</code>.</p>
     */
    @io.qt.QtUninvokable
    public final int indexOfClassName(java.lang.String className) {
        return indexOfClassName(className, (boolean)true);
    }
    
    @io.qt.QtUninvokable
    public int indexOfClassName(java.lang.String className, boolean resolveName){
        return indexOfClassName_native_cref_QString_bool_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), className, resolveName);
    }
    
    @io.qt.QtUninvokable
    private native int indexOfClassName_native_cref_QString_bool_constfct(long __this__nativeId, java.lang.String className, boolean resolveName);
    
    /**
     * <p>Overloaded function for {@link #indexOfObject(io.qt.core.QObject, boolean)}
     *  with <code>resolveName = true</code>.</p>
     */
    @io.qt.QtUninvokable
    public final int indexOfObject(io.qt.core.QObject object) {
        return indexOfObject(object, (boolean)true);
    }
    
    @io.qt.QtUninvokable
    public int indexOfObject(io.qt.core.QObject object, boolean resolveName){
        return indexOfObject_native_QObject_ptr_bool_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(object), resolveName);
    }
    
    @io.qt.QtUninvokable
    private native int indexOfObject_native_QObject_ptr_bool_constfct(long __this__nativeId, long object, boolean resolveName);
    
    @io.qt.QtUninvokable
    public void insert(int index, io.qt.designer.QDesignerWidgetDataBaseItemInterface item){
        insert_native_int_QDesignerWidgetDataBaseItemInterface_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), index, QtJambi_LibraryUtilities.internal.checkedNativeId(item));
    }
    
    @io.qt.QtUninvokable
    private native void insert_native_int_QDesignerWidgetDataBaseItemInterface_ptr(long __this__nativeId, int index, long item);
    
    @io.qt.QtUninvokable
    public io.qt.designer.QDesignerWidgetDataBaseItemInterface item(int index){
        return item_native_int_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), index);
    }
    
    @io.qt.QtUninvokable
    private native io.qt.designer.QDesignerWidgetDataBaseItemInterface item_native_int_constfct(long __this__nativeId, int index);
    
    @io.qt.QtUninvokable
    protected final void setItems(java.util.Collection<? extends io.qt.designer.QDesignerWidgetDataBaseItemInterface> items){
        setItems_native_cref_QList(QtJambi_LibraryUtilities.internal.nativeId(this), items);
    }
    
    @io.qt.QtUninvokable
    private native void setItems_native_cref_QList(long __this__nativeId, java.util.Collection<? extends io.qt.designer.QDesignerWidgetDataBaseItemInterface> items);
    
    @io.qt.QtUninvokable
    protected final io.qt.core.QList<io.qt.designer.QDesignerWidgetDataBaseItemInterface> items(){
        return items_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QList<io.qt.designer.QDesignerWidgetDataBaseItemInterface> items_native(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QDesignerWidgetDataBaseInterface(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QDesignerWidgetDataBaseInterface(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QDesignerWidgetDataBaseInterface instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-designer-6.2-sources.jar: io/qt/designer/QDesignerWidgetDataBaseInterface.java <==
package io.qt.designer;


/**
 * <p>Java wrapper for Qt class QDesignerWidgetDataBaseInterface</p>
 */
public class QDesignerWidgetDataBaseInterface extends io.qt.core.QObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QDesignerWidgetDataBaseInterface.class);
    

    public final Signal0 changed = new Signal0();
    
    /**
     * <p>Overloaded constructor for {@link #QDesignerWidgetDataBaseInterface(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QDesignerWidgetDataBaseInterface() {
        this((io.qt.core.QObject)null);
    }
    
    public QDesignerWidgetDataBaseInterface(io.qt.core.QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QDesignerWidgetDataBaseInterface instance, io.qt.core.QObject parent);
    
    /**
     * <p>Overloaded function for {@link #isContainer(io.qt.core.QObject, boolean)}
     *  with <code>resolveName = true</code>.</p>
     */
    @io.qt.QtUninvokable
    public final boolean isContainer(io.qt.core.QObject object) {
        return isContainer(object, (boolean)true);
    }
    
    @io.qt.QtUninvokable
    public final boolean isContainer(io.qt.core.QObject object, boolean resolveName){
        return isContainer_native_QObject_ptr_bool_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(object), resolveName);
    }
    
    @io.qt.QtUninvokable
    private native boolean isContainer_native_QObject_ptr_bool_constfct(long __this__nativeId, long object, boolean resolveName);
    
    /**
     * <p>Overloaded function for {@link #isCustom(io.qt.core.QObject, boolean)}
     *  with <code>resolveName = true</code>.</p>
     */
    @io.qt.QtUninvokable
    public final boolean isCustom(io.qt.core.QObject object) {
        return isCustom(object, (boolean)true);
    }
    
    @io.qt.QtUninvokable
    public final boolean isCustom(io.qt.core.QObject object, boolean resolveName){
        return isCustom_native_QObject_ptr_bool_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(object), resolveName);
    }
    
    @io.qt.QtUninvokable
    private native boolean isCustom_native_QObject_ptr_bool_constfct(long __this__nativeId, long object, boolean resolveName);
    
    @io.qt.QtUninvokable
    public void append(io.qt.designer.QDesignerWidgetDataBaseItemInterface item){
        append_native_QDesignerWidgetDataBaseItemInterface_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(item));
    }
    
    @io.qt.QtUninvokable
    private native void append_native_QDesignerWidgetDataBaseItemInterface_ptr(long __this__nativeId, long item);
    
    @io.qt.QtUninvokable
    public io.qt.designer.QDesignerFormEditorInterface core(){
        return core_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.designer.QDesignerFormEditorInterface core_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public int count(){
        return count_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int count_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public int indexOf(io.qt.designer.QDesignerWidgetDataBaseItemInterface item){
        return indexOf_native_QDesignerWidgetDataBaseItemInterface_ptr_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(item));
    }
    
    @io.qt.QtUninvokable
    private native int indexOf_native_QDesignerWidgetDataBaseItemInterface_ptr_constfct(long __this__nativeId, long item);
    
    /**
     * <p>Overloaded function for {@link #indexOfClassName(java.lang.String, boolean)}
     *  with <code>resolveName = true</code>.</p>
     */
    @io.qt.QtUninvokable
    public final int indexOfClassName(java.lang.String className) {
        return indexOfClassName(className, (boolean)true);
    }
    
    @io.qt.QtUninvokable
    public int indexOfClassName(java.lang.String className, boolean resolveName){
        return indexOfClassName_native_cref_QString_bool_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), className, resolveName);
    }
    
    @io.qt.QtUninvokable
    private native int indexOfClassName_native_cref_QString_bool_constfct(long __this__nativeId, java.lang.String className, boolean resolveName);
    
    /**
     * <p>Overloaded function for {@link #indexOfObject(io.qt.core.QObject, boolean)}
     *  with <code>resolveName = true</code>.</p>
     */
    @io.qt.QtUninvokable
    public final int indexOfObject(io.qt.core.QObject object) {
        return indexOfObject(object, (boolean)true);
    }
    
    @io.qt.QtUninvokable
    public int indexOfObject(io.qt.core.QObject object, boolean resolveName){
        return indexOfObject_native_QObject_ptr_bool_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(object), resolveName);
    }
    
    @io.qt.QtUninvokable
    private native int indexOfObject_native_QObject_ptr_bool_constfct(long __this__nativeId, long object, boolean resolveName);
    
    @io.qt.QtUninvokable
    public void insert(int index, io.qt.designer.QDesignerWidgetDataBaseItemInterface item){
        insert_native_int_QDesignerWidgetDataBaseItemInterface_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), index, QtJambi_LibraryUtilities.internal.checkedNativeId(item));
    }
    
    @io.qt.QtUninvokable
    private native void insert_native_int_QDesignerWidgetDataBaseItemInterface_ptr(long __this__nativeId, int index, long item);
    
    @io.qt.QtUninvokable
    public io.qt.designer.QDesignerWidgetDataBaseItemInterface item(int index){
        return item_native_int_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), index);
    }
    
    @io.qt.QtUninvokable
    private native io.qt.designer.QDesignerWidgetDataBaseItemInterface item_native_int_constfct(long __this__nativeId, int index);
    
    @io.qt.QtUninvokable
    protected final void setItems(java.util.Collection<io.qt.designer.QDesignerWidgetDataBaseItemInterface> items){
        setItems_native_cref_QList(QtJambi_LibraryUtilities.internal.nativeId(this), items);
    }
    
    @io.qt.QtUninvokable
    private native void setItems_native_cref_QList(long __this__nativeId, java.util.Collection<io.qt.designer.QDesignerWidgetDataBaseItemInterface> items);
    
    @io.qt.QtUninvokable
    protected final io.qt.core.QList<io.qt.designer.QDesignerWidgetDataBaseItemInterface> items(){
        return items_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QList<io.qt.designer.QDesignerWidgetDataBaseItemInterface> items_native(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QDesignerWidgetDataBaseInterface(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QDesignerWidgetDataBaseInterface(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QDesignerWidgetDataBaseInterface instance, QDeclarativeConstructor constructor);
    
}
